@@ -25,6 +25,7 @@ type UI struct {
 	orange    *color.Color
 	blue      *color.Color
 	summarize bool
+	noPrefix  bool
 }
 
 var progressRunes = []rune(`⠇⠏⠋⠙⠹⠸⠼⠴⠦⠧`)
@@ -39,6 +40,7 @@ func CreateStdoutUI(
 	summarize bool,
 	constGC bool,
 	useSIPrefix bool,
+	noPrefix bool,
 ) *UI {
 	ui := &UI{
 		UI: &common.UI{
@@ -52,6 +54,7 @@ func CreateStdoutUI(
 		},
 		output:    output,
 		summarize: summarize,
+		noPrefix:  noPrefix,
 	}
 
 	ui.red = color.New(color.FgRed).Add(color.Bold)
@@ -162,7 +165,7 @@ func (ui *UI) AnalyzePath(path string, _ fs.Item) error {
 }
 
 func (ui *UI) showDir(dir fs.Item) {
-	sort.Sort(dir.GetFiles())
+	sort.Sort(sort.Reverse(dir.GetFiles()))
 
 	for _, file := range dir.GetFiles() {
 		ui.printItem(file)
@@ -265,7 +268,11 @@ func (ui *UI) ReadAnalysis(input io.Reader) error {
 		return err
 	}
 
-	ui.showDir(dir)
+	if ui.summarize {
+		ui.printTotalItem(dir)
+	} else {
+		ui.showDir(dir)
+	}
 
 	return nil
 }
@@ -332,6 +339,9 @@ func (ui *UI) updateProgress() {
 }
 
 func (ui *UI) formatSize(size int64) string {
+	if ui.noPrefix {
+		return ui.orange.Sprintf("%d", size)
+	}
 	if ui.UseSIPrefix {
 		return ui.formatWithDecPrefix(size)
 	}
